Welcome to drizzlepac’s documentation! — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Welcome to drizzlepac’s documentation!

This package supports the use of MultiDrizzle as an integrated set of modules that can be run in an automated manner to combine images. The version of MultiDrizzle described here implements a single task to run the entire MultiDrizzle processing pipeline, while also providing the framework for users to create their own custom pipeline based on the modules in this package merged with their own custom code if desired.

This package relies on the STWCS and PyWCS packages in order to provide the support for the WCS-based distortion models and alignment of the input images.

Contents:

- Primary User Interface: AstroDrizzle()
- imageObject Classes
  - Base ImageObject Classes
  - ACS ImageObjects
  - WFC3 ImageObjects
  - STIS ImageObjects
  - NICMOS ImageObjects
  - WFPC2 ImageObjects
- Step 1: Process Input
  - ResetBits Update of Input
- Step 2: Generate a Static Mask
- Step 3: Subtracting the Sky
- Step 4 and 8: Drizzling the Images
- Step 5: Create a Median Image
- Step 6: Blotting the Median Image
- Step 7: Cosmic-ray identification
- Utilities
  - Utility Functions
  - WCS Utilities
  - Output Image Generation
  - MultiDrizzle Reference Table

## DrizzlePac Release Notes

The code for this package gets released through a number of methods: namely, the use of the package for pipeline and archive processing of ACS and WFC3 data, SSB’s semi-annual public release of the stsci_python package, and a weekly beta release of the development version. The following notes provide some details on what has been revised for each version.

- DrizzlePac Release Notes

## Image Registration Tasks

Documentation for the replacement task for IRAF’s tweakshifts, currently named tweakreg, has been added to this package. These new modules describe how to run the new TEAL-enabled task, as well as use the classes in the task to generate catalogs interactively for any chip and work with that catalog. The current implementation of this code relies on a very basic source finding algorithm loosely patterned after the DAOFIND algorithm and does not provide all the same features or outputs found in DAOFIND. The fitting algorithm also reproduces the fitting performed by IRAF’s geomap in a limited fashion; primarily, without iterations of outliers and only to perform fits equivalent to geomap‘s ‘shift’ and ‘rscale’ solutions. These algorithms will be upgraded as soon as replacements are available.

- TWEAKREG: Alignment of Images
- Imagefindpars: Source finding parameters
  - Parameters
- Image Class
- Classes to manage Catalogs and WCS’s
- Functions to Manage WCS Table Extension
- Functions to Manage Legacy OPUS WCS Keywords in the WCS Table
- TWEAKUTILS: Utility Functions for Tweakreg
- UPDATEHDR: Functions for Updating WCS with New Solutions

## Coordinate Transformation Tasks

These tasks support transformations of source positions to and from distorted and drizzled images.

- pixtopix: Coordinate transformation to/from drizzled images
- pixtosky: Coordinate transformation to sky coordinates
- skytopix: Coordinate transformation from sky coordinates

## ACS Header Update Task

A task, ‘updatenpol’, has been written to automate the updating of ACS image headers with the filename of the appropriate NPOLFILE based on the DGEOFILE specified in the image header. This task should be used to update all ACS images prior to processing them with ‘astrodrizzle’.

- Updatenpol

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »